Python-FSPS is developed by (alphabetical by last name):

* `Dan Foreman-Mackey <https://github.com/dfm>`_
* `Ben Johnson <https://github.com/bd-j>`_
* `Jonathan Sick <https://github.com/jonathansick>`_
